Struct pallet_balances::AccountData [−][src]
pub struct AccountData<Balance> {
pub free: Balance,
pub reserved: Balance,
pub misc_frozen: Balance,
pub fee_frozen: Balance,
}Expand description
All balance information for an account.
Fields
free: BalanceNon-reserved part of the balance. There may still be restrictions on this, but it is the total pool what may in principle be transferred, reserved and used for tipping.
This is the only balance that matters in terms of most operations on tokens. It alone is used to determine the balance when in the contract execution environment.
reserved: BalanceBalance which is reserved and may not be used at all.
This can still get slashed, but gets slashed last of all.
This balance is a ‘reserve’ balance that other subsystems use in order to set aside tokens that are still ‘owned’ by the account holder, but which are suspendable. This includes named reserve and unnamed reserve.
misc_frozen: BalanceThe amount that free may not drop below when withdrawing for anything except transaction
fee payment.
fee_frozen: BalanceThe amount that free may not drop below when withdrawing specifically for transaction
fee payment.