[−][src]Struct pallet_balances::Module
Methods
impl<T: Trait<I> + 'static, I: Instance> Module<T, I>[src]
pub fn total_issuance() -> T::Balance[src]
The total units issued in the system.
pub fn locks<K: EncodeLike<T::AccountId>>(
key: K
) -> Vec<BalanceLock<T::Balance>>[src]
key: K
) -> Vec<BalanceLock<T::Balance>>
Any liquidity locks on some account balances. NOTE: Should only be accessed when setting, changing and freeing a lock.
impl<T: Trait<I>, I: Instance> Module<T, I>[src]
Can also be called using Call.
pub fn transfer(
origin: T::Origin,
dest: <T::Lookup as StaticLookup>::Source,
value: T::Balance
) -> DispatchResult[src]
origin: T::Origin,
dest: <T::Lookup as StaticLookup>::Source,
value: T::Balance
) -> DispatchResult
Transfer some liquid free balance to another account.
transfer will set the FreeBalance of the sender and receiver.
It will decrease the total issuance of the system by the TransferFee.
If the sender's account is below the existential deposit as a result
of the transfer, the account will be reaped.
The dispatch origin for this call must be Signed by the transactor.
- Dependent on arguments but not critical, given proper implementations for input config types. See related functions below.
- It contains a limited number of reads and writes internally and no complex computation.
Related functions:
ensure_can_withdrawis always called internally but has a bounded complexity.- Transferring balances to accounts that did not exist before will cause
T::OnNewAccount::on_new_accountto be called. - Removing enough funds from an account will trigger
T::DustRemoval::on_unbalanced. transfer_keep_aliveworks the same way astransfer, but has an additional check that the transfer will not kill the origin account.
pub fn force_transfer(
origin: T::Origin,
source: <T::Lookup as StaticLookup>::Source,
dest: <T::Lookup as StaticLookup>::Source,
value: T::Balance
) -> DispatchResult[src]
origin: T::Origin,
source: <T::Lookup as StaticLookup>::Source,
dest: <T::Lookup as StaticLookup>::Source,
value: T::Balance
) -> DispatchResult
Exactly as transfer, except the origin must be root and the source account may be
specified.
pub fn transfer_keep_alive(
origin: T::Origin,
dest: <T::Lookup as StaticLookup>::Source,
value: T::Balance
) -> DispatchResult[src]
origin: T::Origin,
dest: <T::Lookup as StaticLookup>::Source,
value: T::Balance
) -> DispatchResult
impl<T: Trait<I>, I: Instance> Module<T, I>[src]
pub fn free_balance(who: impl Borrow<T::AccountId>) -> T::Balance[src]
Get the free balance of an account.
pub fn usable_balance(who: impl Borrow<T::AccountId>) -> T::Balance[src]
Get the balance of an account that can be used for transfers, reservations, or any other
non-locking, non-transaction-fee activity. Will be at most free_balance.
pub fn usable_balance_for_fees(who: impl Borrow<T::AccountId>) -> T::Balance[src]
Get the balance of an account that can be used for paying transaction fees (not tipping,
or any other kind of fees, though). Will be at most free_balance.
pub fn reserved_balance(who: impl Borrow<T::AccountId>) -> T::Balance[src]
Get the reserved balance of an account.